StringExtensions extension

Extensions for manipulating steam types with ease

on

Methods

clearClassAccess() → String

Available on String, provided by the StringExtensions extension

clears c++ class acccess(::)
clearEnumName() → String

Available on String, provided by the StringExtensions extension

clears prefix E from enums
clearInterfaceName() → String

Available on String, provided by the StringExtensions extension

clears prefix I from interfaces
clearPointerOrConst() → String

Available on String, provided by the StringExtensions extension

clears the const keyword or pointers on a string
clearSteamNaming() → String

Available on String, provided by the StringExtensions extension

clears the steam naming to make it more darty
fixDartConflict() → String

Available on String, provided by the StringExtensions extension

appends a underscore to a cleaned steam keyword if it conflicts with a dart keyword, or function
importPath({String relativeness = "../", Set<String> enumSet = const {}, Set<String> structSet = const {}, Set<String> callbackStructSet = const {}, Set<String> interfaceSet = const {}}) → String

Available on String, provided by the StringExtensions extension

returns the path of type in order to import
toFileName() → String

Available on String, provided by the StringExtensions extension

converts a steam name to proper dart file name
toToken() → Token

Available on String, provided by the StringExtensions extension

converts the current String into Token which can be used to generate code