Token class

Token representation of any steam type in steam api json file This class holds corresponding values for a steam type that will be used in code generation

Constructors

Token({required String typeDart, required String typeFfiDart, required String typeFfiC, required String typeAnnotation, required String fieldAccessor, required String caller, required TokenType tokenType})
const constructor
const

Properties

caller → String
caller of the current type. Current this only changes for Enums. It is counterpart of the field accessor. i.e. EnumType.value
final
fieldAccessor → String
accessor of the current type. Currently this only changes for Enums for example: C returns enums as integer, to be developer friendly code is generated so that the integer values is returned as Dart enums i.e. EnumType.fromValue(integeValue)
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenType → TokenType
TokenType of the token
final
typeAnnotation → String
annotation of the current type. i.e Int()
final
typeDart → String
type to be used in common dart functions. i.e. int, bool etc.
final
typeFfiC → String
type to be used in C part of ffi. i.e. Int, Bool, EnumAlias
final
typeFfiDart → String
type to be used in dart part of ffi. i.e. int, bool, EnumAlias
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited