SteamConst class

Consant definition for steam api

Available extensions

Constructors

SteamConst({required String name, required String type, required String value})
Creates a SteamConst. This constructor is used for manual SteamConst creation
SteamConst.fromJson(Map<String, dynamic> json)
Creates a SteamConst from json

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
name of the constant
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
c type of the constant
getter/setter pair
value String
value of the constant
getter/setter pair

Methods

generate({required IOSink fileSink}) → void

Available on SteamConst, provided by the SteamConstExtensions extension

Generates necessary code for a SteamConst
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited