SteamInterface class

Interface definition for steam api

Available extensions

Constructors

SteamInterface({required String name, String versionString = "", List<SteamField> fields = const [], List<SteamMethod> methods = const [], List<SteamAccessor> accessors = const [], List<SteamEnum> enums = const []})
Creates a SteamInterface. This constructor is used for manual SteamInterface creation
SteamInterface.fromJson(Map<String, dynamic> json)
Creates a SteamInterface from json

Properties

accessors ↔ List<SteamAccessor>
list of SteamAccessors of the interface
getter/setter pair
enums ↔ List<SteamEnum>
list of SteamEnums of the interface
getter/setter pair
fields ↔ List<SteamField>
list of SteamFields of the interface
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
methods ↔ List<SteamMethod>
list of SteamMethods of the interface
getter/setter pair
name ↔ String
name of the interface
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionString ↔ String
version of the interface
getter/setter pair

Methods

generate({required IOSink fileSink, Set<String> enumSet = const {}, Set<String> structSet = const {}, Set<String> callbackStructSet = const {}, Set<String> interfaceSet = const {}}) → void

Available on SteamInterface, provided by the SteamInterfaceExtensions extension

Generates necessary code for a SteamInterface
generateFile({required String path, required IOSink exportSink, Set<String> enumSet = const {}, Set<String> structSet = const {}, Set<String> callbackStructSet = const {}, Set<String> interfaceSet = const {}}) → Future<void>

Available on SteamInterface, provided by the SteamInterfaceExtensions extension

Generates necessary file and code for a SteamInterface
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited